==> react-atom-pin-input-1.5.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["children", "defaultValue", "disabled", "inputMode", "isOneTimeCode", "isPassword", "length", "mask", "onChange", "placeholder", "size", "status", "value"];
import { forwardRef, useCallback, useEffect, useRef } from 'react';
import PropTypes from 'prop-types';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs';
import { MASK, SIZES, STATUS, getValueType, BASE_CLASSNAME } from './config';
import useUpdateEffect from './hooks/useUpdateEffect';
import useKeyPress from './hooks/useKeyPress';
import { actions as pinInputActions, usePinInputReducer } from './reducer';
import { PinInputContextProvider } from './PinInputContext';
import PinInputChildren from './PinInputChildren';
import PinInputField from './PinInputField';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var CLASSNAME = BASE_CLASSNAME;
var PinInput = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var children = _ref.children,
      _ref$defaultValue = _ref.defaultValue,
      defaultValue = _ref$defaultValue === void 0 ? '' : _ref$defaultValue,
      disabled = _ref.disabled,
      inputMode = _ref.inputMode,
      _ref$isOneTimeCode = _ref.isOneTimeCode,
      isOneTimeCode = _ref$isOneTimeCode === void 0 ? true : _ref$isOneTimeCode,
      _ref$isPassword = _ref.isPassword,
      isPassword = _ref$isPassword === void 0 ? false : _ref$isPassword,
      _ref$length = _ref.length,
      length = _ref$length === void 0 ? 6 : _ref$length,
      mask = _ref.mask,
      onChange = _ref.onChange,
      _ref$placeholder = _ref.placeholder,
      placeholder = _ref$placeholder === void 0 ? '' : _ref$placeholder,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? SIZES.MEDIUM : _ref$size,
      status = _ref.status,
      value = _ref.value,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var innerRef = useRef();
  var targetRef = useRef();

  var _usePinInputReducer = usePinInputReducer({
    mask: mask,
    defaultValue: defaultValue,
    value: value,
    disabled: disabled
  }),
      reducerStore = _usePinInputReducer[0],
      dispatch = _usePinInputReducer[1];

  var innerValue = reducerStore.innerValue,
      focusPosition = reducerStore.focusPosition,
      elements = reducerStore.elements;
  useUpdateEffect(function () {
    var innerValue = typeof value === 'string' ? value.split('') : value || [];
    dispatch(pinInputActions.setValue({
      innerValue: innerValue
    }));
  }, ["" + value, dispatch]);
  useEffect(function () {
    dispatch(pinInputActions.setDisabled({
      disabled: disabled
    }));
  }, [disabled, dispatch]);
  useEffect(function () {
    dispatch(pinInputActions.setMask({
      mask: mask
    }));
  }, [mask, dispatch]);
  var setFocus = useCallback(function (position) {
    dispatch(pinInputActions.setFocus({
      focusPosition: position
    }));
  }, [dispatch]);
  useKeyPress(function (event) {
    dispatch(pinInputActions.setKey({
      event: event,
      onChange: onChange
    }));
  }, {
    target: targetRef,
    onChange: onChange
  });
  var getIndex = useCallback(function (node) {
    return elements.indexOf(node);
  }, [elements]);
  useUpdateEffect(function () {
    setFocus(focusPosition);
  }, [focusPosition]);
  return /*#__PURE__*/_jsxs("div", {
    className: CLASSNAME,
    ref: targetRef,
    children: [/*#__PURE__*/_jsx(PinInputContextProvider, {
      disabled: reducerStore.disabled,
      dispatch: dispatch,
      getIndex: getIndex,
      inputMode: inputMode,
      isOneTimeCode: isOneTimeCode,
      isPassword: isPassword,
      mask: reducerStore.mask,
      placeholder: placeholder,
      setFocus: setFocus,
      size: size,
      status: status,
      targetRef: innerRef,
      value: innerValue,
      children: /*#__PURE__*/_jsx(PinInputChildren, {
        length: length,
        children: children
      })
    }), /*#__PURE__*/_jsx("input", {
      type: "hidden",
      value: innerValue.filter(Boolean).join(''),
      ref: useMergeRefs(innerRef, forwardedRef)
    })]
  });
});
PinInput.displayName = 'PinInput';
export default PinInput;
export { PinInputField, MASK as pinInputMask, SIZES as pinInputSizes, STATUS as pinInputStatus, getValueType as getPinInputValueType };

==> react-atom-pin-input-1.7.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["autoFocus", "children", "defaultValue", "disabled", "inputMode", "isOneTimeCode", "isPassword", "length", "mask", "onChange", "placeholder", "size", "status", "value"];
import { forwardRef, useCallback, useEffect, useRef } from 'react';
import PropTypes from 'prop-types';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs';
import { MASK, SIZES, STATUS, getValueType, BASE_CLASSNAME } from './config.js';
import useUpdateEffect from './hooks/useUpdateEffect.js';
import useKeyPress from './hooks/useKeyPress.js';
import { actions as pinInputActions, usePinInputReducer } from './reducer/index.js';
import { PinInputContextProvider } from './PinInputContext.js';
import PinInputChildren from './PinInputChildren.js';
import PinInputField from './PinInputField.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var CLASSNAME = BASE_CLASSNAME;
var PinInput = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var _ref$autoFocus = _ref.autoFocus,
      autoFocus = _ref$autoFocus === void 0 ? false : _ref$autoFocus,
      children = _ref.children,
      _ref$defaultValue = _ref.defaultValue,
      defaultValue = _ref$defaultValue === void 0 ? '' : _ref$defaultValue,
      disabled = _ref.disabled,
      inputMode = _ref.inputMode,
      _ref$isOneTimeCode = _ref.isOneTimeCode,
      isOneTimeCode = _ref$isOneTimeCode === void 0 ? true : _ref$isOneTimeCode,
      _ref$isPassword = _ref.isPassword,
      isPassword = _ref$isPassword === void 0 ? false : _ref$isPassword,
      _ref$length = _ref.length,
      length = _ref$length === void 0 ? 6 : _ref$length,
      mask = _ref.mask,
      onChange = _ref.onChange,
      _ref$placeholder = _ref.placeholder,
      placeholder = _ref$placeholder === void 0 ? '' : _ref$placeholder,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? SIZES.MEDIUM : _ref$size,
      status = _ref.status,
      value = _ref.value,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var innerRef = useRef();
  var targetRef = useRef();

  var _usePinInputReducer = usePinInputReducer({
    mask: mask,
    defaultValue: defaultValue,
    value: value,
    disabled: disabled
  }),
      reducerStore = _usePinInputReducer[0],
      dispatch = _usePinInputReducer[1];

  var innerValue = reducerStore.innerValue,
      focusPosition = reducerStore.focusPosition,
      elements = reducerStore.elements;
  useUpdateEffect(function () {
    var innerValue = typeof value === 'string' ? value.split('') : value || [];
    dispatch(pinInputActions.setValue({
      innerValue: innerValue
    }));
  }, ["" + value, dispatch]);
  useEffect(function () {
    dispatch(pinInputActions.setDisabled({
      disabled: disabled
    }));
  }, [disabled, dispatch]);
  useEffect(function () {
    dispatch(pinInputActions.setMask({
      mask: mask
    }));
  }, [mask, dispatch]);
  var setFocus = useCallback(function (position) {
    dispatch(pinInputActions.setFocus({
      focusPosition: position
    }));
  }, [dispatch]);
  useKeyPress(function (event) {
    dispatch(pinInputActions.setKey({
      event: event,
      onChange: onChange
    }));
  }, {
    target: targetRef,
    onChange: onChange
  });
  var getIndex = useCallback(function (node) {
    return elements.indexOf(node);
  }, [elements]);
  useUpdateEffect(function () {
    setFocus(focusPosition);
  }, [focusPosition]);
  return /*#__PURE__*/_jsxs("div", {
    className: CLASSNAME,
    ref: targetRef,
    children: [/*#__PURE__*/_jsx(PinInputContextProvider, {
      disabled: reducerStore.disabled,
      dispatch: dispatch,
      getIndex: getIndex,
      inputMode: inputMode,
      isOneTimeCode: isOneTimeCode,
      isPassword: isPassword,
      mask: reducerStore.mask,
      placeholder: placeholder,
      setFocus: setFocus,
      size: size,
      status: status,
      targetRef: innerRef,
      value: innerValue,
      children: /*#__PURE__*/_jsx(PinInputChildren, {
        length: length,
        autoFocus: autoFocus,
        children: children
      })
    }), /*#__PURE__*/_jsx("input", {
      type: "hidden",
      value: innerValue.filter(Boolean).join(''),
      ref: useMergeRefs(innerRef, forwardedRef)
    })]
  });
});
PinInput.displayName = 'PinInput';
export default PinInput;
export { PinInputField, MASK as pinInputMask, SIZES as pinInputSizes, STATUS as pinInputStatus, getValueType as getPinInputValueType };
